@@ -29,8 +29,8 @@ class BackendChooseDialog : public QDialog
 {
   Q_OBJECT
   public:
-    BackendChooseDialog( QWidget* parent);
-    ~BackendChooseDialog() override;
+    explicit BackendChooseDialog( QWidget* parent);
+    ~BackendChooseDialog() override = default;
 
     QString backendName();
 
