@@ -252,8 +252,7 @@ void TestJulia::testAutoCompletion()
 {
     auto prefix = QLatin1String("ex");
     auto completionObject = session()->completionFor(prefix);
-    // Give sometime for Qt's singleShot in fetch completions to trigger
-    QTest::qWait(1000);
+    waitForSignal(completionObject, SIGNAL(fetchingDone()));
     auto completions = completionObject->completions();
 
     QStringList completionsToCheck;
@@ -270,5 +269,26 @@ void TestJulia::testAutoCompletion()
     }
 }
 
+void TestJulia::testComplexAutocompletion()
+{
+    auto prefix = QLatin1String("Base.Ma");
+    auto completionObject = session()->completionFor(prefix);
+    waitForSignal(completionObject, SIGNAL(fetchingDone()));
+    auto completions = completionObject->completions();
+
+    QStringList completionsToCheck;
+    completionsToCheck << QLatin1String("Base.MainInclude");
+    completionsToCheck << QLatin1String("Base.Math");
+    completionsToCheck << QLatin1String("Base.Matrix");
+
+    for (auto completion : completionsToCheck) {
+        QVERIFY(completions.contains(completion));
+    }
+
+    for (auto completion : completions) {
+        QVERIFY(completion.startsWith(prefix));
+    }
+}
+
 QTEST_MAIN(TestJulia)
 
