@@ -29,11 +29,12 @@ class MaximaHighlighter : public Cantor::DefaultHighlighter
   Q_OBJECT
   public:
     MaximaHighlighter( QObject* parent, MaximaSession* session);
-    ~MaximaHighlighter() override;
+    ~MaximaHighlighter() override = default;
 
   protected:
-    void highlightBlock(const QString &text) Q_DECL_OVERRIDE;
+    void highlightBlock(const QString &text) override;
 
+    QString nonSeparatingCharacters() const override;
   private Q_SLOTS:
       void addUserVariables(const QStringList variables);
       void removeUserVariables(const QStringList variables);
