@@ -28,57 +28,45 @@
 class MaximaExpression;
 class MaximaVariableModel;
 
-#ifdef Q_OS_WIN
-  class KProcess;
-#else
-  class KPtyProcess;
-#endif
-
 class MaximaSession : public Cantor::Session
 {
   Q_OBJECT
   public:
     static const QRegExp MaximaOutputPrompt;
+    static const QRegExp MaximaInputPrompt;
 
-    MaximaSession( Cantor::Backend* backend);
+    explicit MaximaSession( Cantor::Backend* backend);
 
-    void login() Q_DECL_OVERRIDE;
-    void logout() Q_DECL_OVERRIDE;
+    void login() override;
+    void logout() override;
 
-    Cantor::Expression* evaluateExpression(const QString& command, Cantor::Expression::FinishingBehavior behave) Q_DECL_OVERRIDE;
+    Cantor::Expression* evaluateExpression(const QString& command, Cantor::Expression::FinishingBehavior behave = Cantor::Expression::FinishingBehavior::DoNotDelete, bool internal = false) override;
 
-    void appendExpressionToQueue(MaximaExpression* expr);
+    void interrupt() override;
+    void sendInputToProcess(const QString&);
 
-    void interrupt() Q_DECL_OVERRIDE;
-    void interrupt(MaximaExpression* expr);
-    void sendInputToProcess(const QString& input);
+    void setTypesettingEnabled(bool) override;
 
-    void setTypesettingEnabled(bool enable) Q_DECL_OVERRIDE;
-
-    Cantor::CompletionObject* completionFor(const QString& command, int index=-1) Q_DECL_OVERRIDE;
-    Cantor::SyntaxHelpObject* syntaxHelpFor(const QString& command) Q_DECL_OVERRIDE;
-    QSyntaxHighlighter* syntaxHighlighter(QObject* parent) Q_DECL_OVERRIDE;
-    QAbstractItemModel* variableModel() Q_DECL_OVERRIDE;
+    Cantor::CompletionObject* completionFor(const QString& command, int index=-1) override;
+    Cantor::SyntaxHelpObject* syntaxHelpFor(const QString& command) override;
+    QSyntaxHighlighter* syntaxHighlighter(QObject*) override;
+    QAbstractItemModel* variableModel() override;
+    void runFirstExpression() override;
 
   public Q_SLOTS:
     void readStdOut();
     void readStdErr();
 
   private Q_SLOTS:
-    void currentExpressionChangedStatus(Cantor::Expression::Status status);
+    void currentExpressionChangedStatus(Cantor::Expression::Status);
     void restartMaxima();
     void restartsCooledDown();
-
-    void runFirstExpression();
-    void killLabels();
-
-    void reportProcessError(QProcess::ProcessError error);
+    void reportProcessError(QProcess::ProcessError);
 
   private:
     void write(const QString&);
 
     QProcess* m_process;
-    QList<MaximaExpression*> m_expressionQueue;
     QString m_cache;
     MaximaVariableModel* m_variableModel;
     bool m_justRestarted;
