@@ -37,19 +37,20 @@ MaximaVariableModel::MaximaVariableModel( MaximaSession* session) : Cantor::Defa
 
 }
 
-MaximaVariableModel::~MaximaVariableModel()
+void MaximaVariableModel::clear()
 {
-
+    emit functionsRemoved(functionNames());
+    emit variablesRemoved(variableNames());
+    m_functions.clear();
+    m_variables.clear();
+    DefaultVariableModel::clearVariables();
 }
 
-
-
 void MaximaVariableModel::checkForNewVariables()
 {
     qDebug()<<"checking for new variables";
     const QString& cmd=variableInspectCommand.arg(QLatin1String("values"));
-    Cantor::Expression* expr=session()->evaluateExpression(cmd);
-    expr->setInternal(true);
+    Cantor::Expression* expr=session()->evaluateExpression(cmd, Cantor::Expression::FinishingBehavior::DoNotDelete, true);
     connect(expr, &Cantor::Expression::statusChanged, this, &MaximaVariableModel::parseNewVariables);
 }
 
@@ -57,50 +58,61 @@ void MaximaVariableModel::checkForNewFunctions()
 {
     qDebug()<<"checking for new functions";
     const QString& cmd=inspectCommand.arg(QLatin1String("functions"));
-    Cantor::Expression* expr=session()->evaluateExpression(cmd);
-    expr->setInternal(true);
+    Cantor::Expression* expr=session()->evaluateExpression(cmd, Cantor::Expression::FinishingBehavior::DoNotDelete, true);
 
     connect(expr, &Cantor::Expression::statusChanged, this, &MaximaVariableModel::parseNewFunctions);
 }
 
 QList<Cantor::DefaultVariableModel::Variable> parse(MaximaExpression* expr)
 {
-    qDebug()<<"parsing it!";
-    if(!expr||expr->status()!=Cantor::Expression::Done||
-       !expr->result())
-        return QList<Cantor::DefaultVariableModel::Variable>();
-
-    QString text;
-    if(expr->result()->type()==Cantor::TextResult::Type)
-        text=dynamic_cast<Cantor::TextResult*>(expr->result())->plain();
-    else if(expr->result()->type()==Cantor::LatexResult::Type)
-        text=dynamic_cast<Cantor::LatexResult*>(expr->result())->plain();
-    else
-    {
-        qDebug()<<"unsupported type: "<<expr->result()->type()<<endl;
+    if(!expr || expr->status()!=Cantor::Expression::Done || expr->results().isEmpty()) {
         return QList<Cantor::DefaultVariableModel::Variable>();
     }
 
-
-    qDebug()<<"got "<<text;
+    //for parsing of names and values below (old code) we need to combine multiple results back to one string
+    QString text;
+    for (auto* result : expr->results())
+    {
+        if(result->type()==Cantor::TextResult::Type)
+            text += dynamic_cast<Cantor::TextResult*>(result)->plain();
+        else if(expr->result()->type()==Cantor::LatexResult::Type)
+            text += dynamic_cast<Cantor::LatexResult*>(result)->plain();
+    }
 
     const int nameIndex=text.indexOf(QLatin1Char(']'));
-    qDebug()<<"idx: "<<nameIndex;
     QString namesString=text.left(nameIndex);
     //namesString.chop(1);
     namesString=namesString.mid(1);
     namesString=namesString.trimmed();
 
-    qDebug()<<"names: "<<namesString;
+    qDebug()<<"variable names: "<<namesString;
     if(namesString.isEmpty())
         return QList<Cantor::DefaultVariableModel::Variable>();
 
-    QStringList variableNames=namesString.split(QLatin1Char(','));
-
-    QString valuesString=text.mid(nameIndex+1).trimmed();
-
-    QStringList variableValues=valuesString.split(QLatin1String("\"-cantor-value-separator-\""));
-    bool hasValues=variableValues.isEmpty();
+    QStringList variableNames;
+    QString valuesString;
+    bool hasValues = false;
+    QStringList variableValues;
+    if ( namesString.contains(QLatin1Char(')')) )
+    {
+        //function definition(s): e.g
+        //text = "[f1(x),f2(x,y),f3(x,y,z)]\n$DONE"
+        //nameString = f1(x),f2(x,y),f3(x,y,z)
+        //variableString = "\n$DONE"
+        variableNames = namesString.split(QLatin1String("),"));
+    }
+    else
+    {
+        //variable definition(s): e.g.
+        //text = "[a,b]\n1\n\"-cantor-value-separator-\"\n2\n\"-cantor-value-separator-\"\n($A $B)"
+        //nameString = "[a,b]"
+        //variableString = "\n1\n\"-cantor-value-separator-\"\n2\n\"-cantor-value-separator-\"\n($A $B)"
+        variableNames = namesString.split(QLatin1Char(','));
+        valuesString = text.mid(nameIndex+1).trimmed();
+        valuesString = valuesString.remove(QLatin1String("\n")); //lists with many elements have line breaks, remove them
+        variableValues = valuesString.split(QLatin1String("\"-cantor-value-separator-\""));
+        hasValues = variableValues.isEmpty();
+    }
 
     qDebug()<<variableNames;
     qDebug()<<"string: "<<valuesString;
@@ -114,31 +126,36 @@ QList<Cantor::DefaultVariableModel::Variable> parse(MaximaExpression* expr)
         Cantor::DefaultVariableModel::Variable var;
         var.name=variableNames.at(i);;
         if(variableValues.size()>i)
+        {
             var.value=variableValues.at(i).trimmed();
+            var.value=var.value.remove(QLatin1String("\n")); //lists with many elements have line breaks, remove them
+        }
         else
             var.value=QLatin1String("unknown");
-        variables<<var;
 
+        variables<<var;
     }
 
     return variables;
 }
 
-void MaximaVariableModel::parseNewVariables()
+void MaximaVariableModel::parseNewVariables(Cantor::Expression::Status status)
 {
+    if (status != Cantor::Expression::Done && status != Cantor::Expression::Error)
+        return;
+
     qDebug()<<"parsing variables";
     MaximaExpression* expr=dynamic_cast<MaximaExpression*>(sender());
 
     QList<Variable> newVars=parse(expr);
-
     QStringList addedVars;
     QStringList removedVars;
     //remove the old variables
-    foreach(const Variable& var,m_variables)
+    for (const Variable& var : m_variables)
     {
         //check if this var is present in the new variables
         bool found=false;
-        foreach(const Variable& var2, newVars)
+        for (const Variable& var2 : newVars)
         {
             if(var.name==var2.name)
             {
@@ -154,7 +171,7 @@ void MaximaVariableModel::parseNewVariables()
         }
     }
 
-    foreach(const Variable& var, newVars)
+    for (const Variable& var : newVars)
     {
         addVariable(var);
 
@@ -170,8 +187,11 @@ void MaximaVariableModel::parseNewVariables()
     emit variablesRemoved(removedVars);
 }
 
-void MaximaVariableModel::parseNewFunctions()
+void MaximaVariableModel::parseNewFunctions(Cantor::Expression::Status status)
 {
+    if (status != Cantor::Expression::Done && status != Cantor::Expression::Error)
+        return;
+
     qDebug()<<"parsing functions";
     MaximaExpression* expr=dynamic_cast<MaximaExpression*>(sender());
 
@@ -180,11 +200,11 @@ void MaximaVariableModel::parseNewFunctions()
     QStringList removedVars;
 
     //remove the old variables
-    foreach(const Variable& var,m_functions)
+    for (const Variable& var : m_functions)
     {
         //check if this var is present in the new variables
         bool found=false;
-        foreach(const Variable& var2, newVars)
+        for (const Variable& var2 : newVars)
         {
             if(var.name==var2.name)
             {
@@ -200,7 +220,7 @@ void MaximaVariableModel::parseNewFunctions()
         }
     }
 
-    foreach(Variable var, newVars)
+    for (Variable var : newVars)
     {
         var.value=i18n("function");
         addVariable(var);
@@ -235,7 +255,7 @@ QList<Cantor::DefaultVariableModel::Variable> MaximaVariableModel::functions()
 QStringList MaximaVariableModel::variableNames()
 {
     QStringList names;
-    foreach(const Cantor::DefaultVariableModel::Variable& var, m_variables)
+    for (const Cantor::DefaultVariableModel::Variable& var : m_variables)
         names<<var.name;
 
     return names;
@@ -244,7 +264,7 @@ QStringList MaximaVariableModel::variableNames()
 QStringList MaximaVariableModel::functionNames(bool stripParameters)
 {
     QStringList names;
-    foreach(const Cantor::DefaultVariableModel::Variable& var, m_functions)
+    for (const Cantor::DefaultVariableModel::Variable& var : m_functions)
     {
         QString name=var.name;
         if(stripParameters)
