@@ -30,16 +30,16 @@ class NullSession : public Cantor::Session
 {
   Q_OBJECT
   public:
-    NullSession( Cantor::Backend* backend);
-    ~NullSession() override;
+    explicit NullSession( Cantor::Backend* backend);
+    ~NullSession() override = default;
 
-    void login() Q_DECL_OVERRIDE;
-    void logout() Q_DECL_OVERRIDE;
+    void login() override;
+    void logout() override;
 
-    void interrupt() Q_DECL_OVERRIDE;
+    void interrupt() override;
 
-    Cantor::Expression* evaluateExpression(const QString& command, Cantor::Expression::FinishingBehavior behave) Q_DECL_OVERRIDE;
-    Cantor::CompletionObject* completionFor(const QString& cmd, int index=-1) Q_DECL_OVERRIDE;
+    Cantor::Expression* evaluateExpression(const QString& command, Cantor::Expression::FinishingBehavior behave = Cantor::Expression::FinishingBehavior::DoNotDelete, bool internal = false) override;
+    Cantor::CompletionObject* completionFor(const QString& cmd, int index=-1) override;
 
   private Q_SLOTS:
     void expressionFinished();
