@@ -27,7 +27,7 @@
 
 #ifdef WITH_EPS
 #include "epsresult.h"
-typedef Cantor::EpsResult OctavePlotResult;
+using OctavePlotResult = Cantor::EpsResult;
 #else
 #include "imageresult.h"
 typedef Cantor::ImageResult OctavePlotResult;
@@ -39,22 +39,23 @@ class OctaveExpression : public Cantor::Expression
     Q_OBJECT
 
 public:
-    OctaveExpression(Cantor::Session*);
+    explicit OctaveExpression(Cantor::Session*, bool internal = false);
 
-    void interrupt() Q_DECL_OVERRIDE;
-    void evaluate() Q_DECL_OVERRIDE;
+    void interrupt() override;
+    void evaluate() override;
     void parseOutput(const QString&);
     void parseError(const QString&);
     void parsePlotFile(const QString&);
 
-    void finalize();
     void setPlotPending(bool);
 
+private:
+    void removeAppendedPlotCommand();
+
 private:
     QString m_resultString;
     bool m_plotPending;
     bool m_finished;
-    bool m_error;
     bool m_appendPlotCommand;
     bool m_appendDot;
     QStringList m_plotCommands;
