@@ -32,10 +32,10 @@ class OctaveSyntaxHelpObject : public Cantor::SyntaxHelpObject
   Q_OBJECT
   public: 
     OctaveSyntaxHelpObject(const QString& command, Cantor::Session* session);
-    ~OctaveSyntaxHelpObject() override;
+    ~OctaveSyntaxHelpObject() override = default;
 
 protected:
-    void fetchInformation() Q_DECL_OVERRIDE;
+    void fetchInformation() override;
     
   private Q_SLOTS:
     void fetchingDone();
