@@ -17,6 +17,7 @@
     ---
     Copyright (C) 2009 Alexander Rieder <alexanderrieder@gmail.com>
     Copyright (C) 2012 Martin Kuettler <martin.kuettler@gmail.com>
+    Copyright (C) 2018 Alexander Semke <alexander.semke@web.de>
  */
 
 #ifndef COMMANDENTRY_H
@@ -30,6 +31,7 @@
 
 class Worksheet;
 class ResultItem;
+class QTimer;
 
 namespace Cantor{
     class Result;
@@ -43,11 +45,11 @@ class CommandEntry : public WorksheetEntry
   public:
     static const QString Prompt;
 
-    CommandEntry(Worksheet* worksheet);
+    explicit CommandEntry(Worksheet* worksheet);
     ~CommandEntry() override;
 
     enum {Type = UserType + 2};
-    int type() const Q_DECL_OVERRIDE;
+    int type() const override;
 
     QString command();
     void setExpression(Cantor::Expression* expr);
@@ -55,43 +57,44 @@ class CommandEntry : public WorksheetEntry
 
     QString currentLine();
 
-    bool isEmpty() Q_DECL_OVERRIDE;
+    bool isEmpty() override;
 
-    void setContent(const QString& content) Q_DECL_OVERRIDE;
-    void setContent(const QDomElement& content, const KZip& file) Q_DECL_OVERRIDE;
+    void setContent(const QString& content) override;
+    void setContent(const QDomElement& content, const KZip& file) override;
 
-    QDomElement toXml(QDomDocument& doc, KZip* archive) Q_DECL_OVERRIDE;
-    QString toPlain(const QString& commandSep, const QString& commentStartingSeq, const QString& commentEndingSeq) Q_DECL_OVERRIDE;
+    QDomElement toXml(QDomDocument& doc, KZip* archive) override;
+    QString toPlain(const QString& commandSep, const QString& commentStartingSeq, const QString& commentEndingSeq) override;
 
     void setCompletion(Cantor::CompletionObject* tc);
     void setSyntaxHelp(Cantor::SyntaxHelpObject* sh);
 
-    bool acceptRichText() Q_DECL_OVERRIDE;
+    bool acceptRichText() override;
 
     void removeContextHelp();
 
-    void interruptEvaluation() Q_DECL_OVERRIDE;
+    void interruptEvaluation() override;
     bool isShowingCompletionPopup();
 
-    bool focusEntry(int pos = WorksheetTextItem::TopLeft, qreal xCoord = 0) Q_DECL_OVERRIDE;
+    bool focusEntry(int pos = WorksheetTextItem::TopLeft, qreal xCoord = 0) override;
 
-    void layOutForWidth(qreal w, bool force = false) Q_DECL_OVERRIDE;
+    void layOutForWidth(qreal w, bool force = false) override;
 
-    WorksheetTextItem* highlightItem() Q_DECL_OVERRIDE;
+    WorksheetTextItem* highlightItem() override;
 
     WorksheetCursor search(const QString& pattern, unsigned flags,
                            QTextDocument::FindFlags qt_flags,
-                           const WorksheetCursor& pos = WorksheetCursor()) Q_DECL_OVERRIDE;
+                           const WorksheetCursor& pos = WorksheetCursor()) override;
 
   public Q_SLOTS:
-    bool evaluateCurrentItem() Q_DECL_OVERRIDE;
-    bool evaluate(WorksheetEntry::EvaluationOption evalOp = FocusNext) Q_DECL_OVERRIDE;
+    bool evaluateCurrentItem() override;
+    bool evaluate(WorksheetEntry::EvaluationOption evalOp = FocusNext) override;
     void addInformation();
-    void removeResult();
+    void removeResults();
+    void removeResult(Cantor::Result* result);
 
-    void showCompletion() Q_DECL_OVERRIDE;
+    void showCompletion() override;
     void selectPreviousCompletion();
-    void updateEntry() Q_DECL_OVERRIDE;
+    void updateEntry() override;
     void updatePrompt();
     void expressionChangedStatus(Cantor::Expression::Status status);
     void showAdditionalInformationPrompt(const QString& question);
@@ -101,23 +104,23 @@ class CommandEntry : public WorksheetEntry
     void showSyntaxHelp();
     void completeLineTo(const QString& line, int index);
 
-    void startRemoving() Q_DECL_OVERRIDE;
+    void startRemoving() override;
 
     void moveToNextItem(int pos, qreal x);
     void moveToPreviousItem(int pos, qreal x);
 
-    void populateMenu(QMenu* menu, QPointF pos) Q_DECL_OVERRIDE;
+    void populateMenu(QMenu* menu, QPointF pos) override;
 
   protected:
-    bool wantToEvaluate() Q_DECL_OVERRIDE;
+    bool wantToEvaluate() override;
 
   private:
     WorksheetTextItem* currentInformationItem();
     bool informationItemHasFocus();
     bool focusWithinThisItem();
     QPoint getPopupPosition();
-
     QPoint toGlobalPosition(QPointF localPos);
+    void initMenus();
 
   private:
     enum CompletionMode {
@@ -127,16 +130,29 @@ class CommandEntry : public WorksheetEntry
   private Q_SLOTS:
     void invalidate();
     void resultDeleted();
+    void clearResultItems();
+    void removeResultItem(int index);
+    void replaceResultItem(int index);
     void updateCompletions();
     void completeCommandTo(const QString& completion, CommandEntry::CompletionMode mode = PreliminaryCompletion);
 
+    void backgroundColorChanged(QAction*);
+    void textColorChanged(QAction*);
+    void fontBoldTriggered();
+    void fontItalicTriggered();
+    void fontIncreaseTriggered();
+    void fontDecreaseTriggered();
+    void fontSelectTriggered();
+
+    void animatePromptItem();
+
   private:
     static const double HorizontalSpacing;
     static const double VerticalSpacing;
 
     WorksheetTextItem* m_promptItem;
     WorksheetTextItem* m_commandItem;
-    ResultItem* m_resultItem;
+    QVector<ResultItem*> m_resultItems;
     WorksheetTextItem* m_errorItem;
     QList<WorksheetTextItem*> m_informationItems;
     Cantor::Expression* m_expression;
@@ -146,6 +162,15 @@ class CommandEntry : public WorksheetEntry
     Cantor::SyntaxHelpObject* m_syntaxHelpObject;
 
     EvaluationOption m_evaluationOption;
+    QPropertyAnimation* m_promptItemAnimation;
+    bool m_menusInitialized;
+
+    //formatting
+    QActionGroup* m_backgroundColorActionGroup;
+    QMenu* m_backgroundColorMenu;
+    QActionGroup* m_textColorActionGroup;
+    QMenu* m_textColorMenu;
+    QMenu* m_fontMenu;
 };
 
 #endif // COMMANDENTRY_H
